@@ -104,7 +104,7 @@ class KubeModel(ABC):
         """
         optimizer = self.configure_optimizers()
         self.optimizer = optimizer
-        self._load_optimizer_redis()
+        self._load_optimizer_state()
   
         # TODO here the state loaded should be the averaged one not the saved from earlier
 
@@ -233,8 +233,9 @@ class KubeModel(ABC):
         Executed after the end of the training loop
         :return:
         """
-        self.__save_model()
-        #pass
+        #self.__save_model()
+        
+        pass
         # self._save_optimizer_state()
 
     def _on_iteration_start(self):
@@ -246,7 +247,7 @@ class KubeModel(ABC):
         :return:
         """
         self.__load_model()
-        self._load_optimizer_redis()
+        self._load_optimizer_state()
         #self._reset_optimizer_state()
 
     def _on_iteration_end(self):
@@ -255,7 +256,7 @@ class KubeModel(ABC):
         :return:
         """
         self.__save_model()
-        self._save_optimizer_redis()
+        self._save_optimizer_state()
 
 
     def _batch_to_device(self, batch: Union[torch.Tensor, Iterable[torch.Tensor]]):
